#
# spec file for package nomacs
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nomacs
Version:        3.4
Release:        2.19
Summary:        Lightweight image viewer
License:        GPL-3.0+
Group:          Productivity/Graphics/Viewers
Url:            http://nomacs.org/
Source:         https://github.com/%{name}/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 2.8
BuildRequires:  gcc-c++
BuildRequires:  libqt5-linguist-devel >= 5.2
BuildRequires:  opencv-qt5-devel >= 2.4.6
BuildRequires:  pkg-config
BuildRequires:  quazip-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.2
BuildRequires:  pkgconfig(Qt5Network) >= 5.2
BuildRequires:  pkgconfig(Qt5PrintSupport) >= 5.2
BuildRequires:  pkgconfig(Qt5Svg) >= 5.2
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2
BuildRequires:  pkgconfig(exiv2) >= 0.25
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libraw) >= 0.17
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(zlib)

%description
nomacs is a free image viewer, which is small, fast and able to handle the
most common image formats. Additionally it is possible to synchronise
multiple viewers. A synchronisation of viewers running on the same
computer or via LAN is possible. It allows to compare images and spot the
differences (e.g. schemes of architects to show the progress).

%prep
%setup -q
sed -i 's/\r$//g' ImageLounge/Readme/*

%build
pushd ImageLounge/
%cmake \
  -DCMAKE_C_FLAGS='%{optflags} -fno-strict-aliasing'   \
  -DCMAKE_CXX_FLAGS='%{optflags} -fno-strict-aliasing' \
  -DCMAKE_SHARED_LINKER_FLAGS=""
make %{?_smp_mflags}
popd

%install
pushd ImageLounge/
%cmake_install
popd
install -Dm 0644 ImageLounge/%{name}.appdata.xml \
  %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

rm %{buildroot}%{_libdir}/lib%{name}*.so
%suse_update_desktop_file %{name}
%find_lang %{name} --with-qt

%post
%desktop_database_post
/sbin/ldconfig

%postun
%desktop_database_postun
/sbin/ldconfig

%files
%defattr(-,root,root)
%doc ImageLounge/Readme/*
%{_bindir}/%{name}
%{_libdir}/lib%{name}*.so.*
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.*
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_mandir}/man?/%{name}.?%{?ext_man}

%changelog
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 3.4:
  * Rework Batch UI.
  * Add Batch Profiles.
  * Cropping to metadata.
  * Improve RGB to Gray.
  * Fix crash on delete.
  * Fix slow thumbnail rendering.
  * Improve start-up time.
  * Fix RAW/PSD orientation.
- Remove nomacs-3.2.0-gcc6.patch: fixed upstream.
- Remove /usr/lib(|64)/libnomacs*.so files: for development, yet
  no development seem possible for nomacs now.
- Add ldconfig to post(|un).
* Fri Jun 17 2016 sor.alexei@meowr.ru
- Add nomacs-3.2.0-gcc6.patch from
  https://github.com/nomacs/nomacs/issues/62: fix GCC6 errors
  (boo#985374).
* Wed May  4 2016 sor.alexei@meowr.ru
- Update to version 3.2.0:
  * Redesign plugin framework.
  * New preferences.
  * Add Undo & History dock.
  * Improve statusbar (e.g. zoom level).
  * All Icons are SVG (UHD monitors).
  * Add compression to Batch.
  * Extend image transitions (swipe).
- Remove nomacs-3.0.0-opencv-detection.patch: fixed upstream.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Add nomacs-3.0.0-opencv-detection.patch to fix detection of
  OpenCV 3.x and later.
* Thu Dec 17 2015 sor.alexei@meowr.ru
- Update to 3.0.0:
  * Add plugins support.
  * Full SVG support.
  * Add Quick Launch.
  * Add Tiny Planet option.
  * Improve batch processing.
  * Add command line arguments.
  * Improve zoom control.
  * Add Bulgarian and Ukrainian translations.
- Remove nomacs-qt5-build-fix.patch.
* Thu Aug 20 2015 sor.alexei@meowr.ru
- Update to 2.4.6:
  * Directory ScrollBar added again (and updated).
  * Fix various crashes (metadata saving/displaying).
  * Fix sorting.
  * Fix some minor bugs.
- Rebase nomacs-qt5-build-fix.patch.
* Fri Apr 17 2015 sor.alexei@meowr.ru
- Update to 2.4.4:
  * Improved batch processing (add images from multiple directories).
  * New Metadata HUD panel (choose entries dynamically).
  * Default strings are now translated.
  * File sorting is (hopefully) fixed.
  * Gamma correction for rescaling is now 16 bit (smooth gradients).
  * Zoom to Fit added (replaces ‘Reset Zoom’).
  * Saving of multiple tabs.
  * UTF-8 encoding for image notes.
  * General stability improvements.
- Rebase nomacs-qt5-build-fix.patch.
* Mon Mar  2 2015 sor.alexei@meowr.ru
- Update to 2.4.2:
  * Image Manipulations are fixed now (black images on e.g. gamma).
  * Resize with gamma correction (black images if gamma was
    checked).
  * Crash fix (if reload occurred after an image resize).
  * Fix Batch Processing.
  * Fix GIF movie toolbar.
  * Update translations.
- Add nomacs-qt5-build-fix.patch.
* Thu Feb 26 2015 sor.alexei@meowr.ru
- Update to 2.4.0:
  * Batch processing (you can try it by clicking
    Tools > Batch Processing).
  * Image tabs (open multiple images within different tabs).
  * Thumbnail preview improved (copy/paste delete/rename is now
    supported).
  * Zoom panel improved (you can now chose a specific zoom level).
  * Olympus RAW added.
  * Convert to grayscale added.
  * Faster directory loading (especially if you have many images
    in a directory).
  * Gesture improvements.
  * Saving of images from archives (e.g. zip, docx) is now supported.
  * File sorting improved.
  * Stability improvements.
- Remove nomacs-strcmp-fix.patch and nomacs-qt5-build-fix.patch.
* Wed Nov 12 2014 sor.alexei@meowr.ru
- Update to 2.2.0:
  * Bugfixes and new features
    (see http://nomacs.org/redmine for details).
- Compile against Qt5 instead of Qt4.
- Rebase nomacs-strcmp-fix.patch.
- Add nomacs-qt5-build-fix.patch.
* Sun Aug  3 2014 sor.alexei@meowr.ru
- Update to 2.0.2.
* Thu Apr 17 2014 sor.alexei@meowr.ru
- Update to 1.6.4.
- Embrace openSUSE packaging policy.
* Sun Feb 24 2013 ti.eugene@gmail.com
- Update to 1.0.
* Thu May 24 2012 petr@scribus.info
- Update to 0.3.2.
* Sat Mar  3 2012 petr@scribus.info
- Update to 0.3.0.
* Mon Dec  5 2011 petr@scribus.info
- Initial package.
